@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 # Mathmaker Lib offers lualatex-printable mathematical objects.
-# Copyright 2006-2017 Nicolas Hainaux <nh.techn@gmail.com>
+# Copyright 2006-2019 Nicolas Hainaux <nh.techn@gmail.com>
 
 # This file is part of Mathmaker Lib.
 
@@ -108,6 +108,8 @@ def test_Sign():
     assert Number(-4) * n == Number(4)
     assert p.evaluate() == Number(1)
     assert n.evaluate() == Number(-1)
+    p.sign = Sign('-')
+    assert p == n
 
 
 def test_copyability():
